<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Erro de expressão </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>Tema escuro</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Modo Simples</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Modo Científico</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Calculadora Deepin</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Calculadora é uma programa simples e fácil de usar no desktop. Ela suporta operações como adição, subtração, multiplicação e divisão.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Erro de expressão </translation>
    </message>
</context>
</TS>